import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { HandedOvers } from '../models/handedOvers';
import { Configuration } from '../configuration';
import { HandedOversServiceInterface } from './handedOvers.serviceInterface';
export declare class HandedOversService implements HandedOversServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one HandedOver.
     * Add one HandedOver.
     * @param HandedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addHandedOver(HandedOvers: HandedOvers, observe?: 'body', reportProgress?: boolean): Observable<HandedOvers>;
    addHandedOver(HandedOvers: HandedOvers, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<HandedOvers>>;
    addHandedOver(HandedOvers: HandedOvers, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<HandedOvers>>;
    /**
     * Delete one HandedOver.
     * Delete one HandedOver.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteHandedOver(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteHandedOver(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteHandedOver(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one HandedOver.
     * Edit one HandedOver.
     * @param HandedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editHandedOver(HandedOvers: HandedOvers, observe?: 'body', reportProgress?: boolean): Observable<HandedOvers>;
    editHandedOver(HandedOvers: HandedOvers, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<HandedOvers>>;
    editHandedOver(HandedOvers: HandedOvers, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<HandedOvers>>;
    /**
     * Get one HandedOver.
     * Get one HandedOver.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getHandedOverById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<HandedOvers>;
    getHandedOverById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<HandedOvers>>;
    getHandedOverById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<HandedOvers>>;
    /**
     * Get all HandedOvers.
     * Get all HandedOvers.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getHandedOvers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<HandedOvers>>;
    getHandedOvers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<HandedOvers>>>;
    getHandedOvers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<HandedOvers>>>;
}
