import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { Memberships } from '../models/memberships';
import { Configuration } from '../configuration';
import { MembershipsServiceInterface } from './memberships.serviceInterface';
export declare class MembershipsService implements MembershipsServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one Membership.
     * Add one Membership.
     * @param HandedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addMembership(HandedOvers: Memberships, observe?: 'body', reportProgress?: boolean): Observable<Memberships>;
    addMembership(HandedOvers: Memberships, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Memberships>>;
    addMembership(HandedOvers: Memberships, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Memberships>>;
    /**
     * Delete one Membership.
     * Delete one Membership.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteMembership(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteMembership(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteMembership(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one Membership.
     * Edit one Membership.
     * @param HandedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editMembership(HandedOvers: Memberships, observe?: 'body', reportProgress?: boolean): Observable<Memberships>;
    editMembership(HandedOvers: Memberships, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Memberships>>;
    editMembership(HandedOvers: Memberships, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Memberships>>;
    /**
     * Get all Memberships.
     * Get all Memberships.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getMemberships(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Memberships>>;
    getMemberships(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Memberships>>>;
    getMemberships(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Memberships>>>;
    /**
     * Get one Membership.
     * Get one Membership.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getMembershipsById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Memberships>;
    getMembershipsById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Memberships>>;
    getMembershipsById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Memberships>>;
}
